@@ -6,7 +6,7 @@ from petl.compat import next, integer_types, string_types, text_type
 
 import petl.config as config
 from petl.errors import ArgumentError, FieldSelectionError
-from petl.util.base import Table, expr, header, Record
+from petl.util.base import Table, expr, fieldnames, Record
 from petl.util.parsers import numparser
 
 
@@ -154,6 +154,21 @@ def convert(table, *args, **kwargs):
         +-----+-------+--------------------+
         | 'C' | '1.2' |               67.2 |
         +-----+-------+--------------------+
+        >>> # conversion can use a custom function
+        >>> def my_func(val, row):
+        ...     return float(row.bar) + row.baz
+        ... 
+        >>> table13 = etl.convert(table1, 'foo', my_func, pass_row=True)
+        >>> table13
+        +------+-------+-----+
+        | foo  | bar   | baz |
+        +======+=======+=====+
+        | 14.4 | '2.4' |  12 |
+        +------+-------+-----+
+        | 39.7 | '5.7' |  34 |
+        +------+-------+-----+
+        | 57.2 | '1.2' |  56 |
+        +------+-------+-----+
 
     Note that either field names or indexes can be given.
 
@@ -227,7 +242,7 @@ def convertall(table, *args, **kwargs):
     """
 
     # TODO don't read the data twice!
-    return convert(table, header(table), *args, **kwargs)
+    return convert(table, fieldnames(table), *args, **kwargs)
 
 
 Table.convertall = convertall
